# Contributing to Papis

## Tips for bug reports

* You can obtain much better error messages with `papis -v --debug`, please
  post those in bug reports too.

## Tips on patching or sending pull requests

* See `HACKING.md`

Thank you!
